@@ -174,7 +174,7 @@ use vars qw/$VERSION @ISA @EXPORT_OK $EOS $LOC $AP $P $PAP @ABBREVIATIONS/;
 use Carp qw/cluck/;
 use English;
 
-our $VERSION = '0.26';
+our $VERSION = '0.27';
 
 # LC_CTYPE now in locale "French, Canada, codeset ISO 8859-1"
 our $LOC;
@@ -196,12 +196,11 @@ our $P = q/[\.!?]/;			## PUNCTUATION
 $AP =  q/(?:'|"|\?|\)|\]|\})?/;	## AFTER PUNCTUATION
 our $PAP = $P.$AP;
 
-my @PEOPLE = qw( jr mr mrs ms dr prof sr sens? reps? gov 
-		attys? supt  det rev );
-
-my @ARMY = qw( col gen lt cmdr adm capt sgt cpl maj );
-my @INSTITUTES = qw( dept univ assn bros );
-my @COMPANIES = qw( inc ltd co corp );
+my @PEOPLE = qw( mr mrs ms dr prof mme ms?gr sens? reps? gov attys? supt  det revd? ald);
+my @TITLE_SUFFIXES = qw(PhD jn?r sn?r esq md llb);
+my @ARMY = qw( col gen lt cmdr adm capt sgt cpl maj pte cdr);
+my @INSTITUTES = qw( dept univ assn bros);
+my @COMPANIES = qw( inc ltd co corp);
 my @PLACES =
 qw(
 	arc al ave blv?d cl ct cres dr expy? 
@@ -216,10 +215,10 @@ qw(
 	Wyo USAFA Alta  Man Ont Qu? Sask Yuk
 );
 my @MONTHS = qw(jan feb mar apr may jun jul aug sep oct nov dec sept);
-my @MISC = qw(no esp );
-my @LATIN = qw(vs etc );
+my @MISC = qw(no esp);
+my @LATIN = qw(vs etc al ibid sic);
 
-our @ABBREVIATIONS = (@PEOPLE, @ARMY, @INSTITUTES, @COMPANIES, @PLACES, @MONTHS, @MISC, @LATIN ); 
+our @ABBREVIATIONS = (@PEOPLE, @TITLE_SUFFIXES, @ARMY, @INSTITUTES, @COMPANIES, @PLACES, @MONTHS, @MISC, @LATIN ); 
 
 
 #==============================================================================
